==> django_small_view_set-0.2.3.tar.gz: django_small_view_set-0.2.3/src/small_view_set/small_view_set.py <==
import inspect
import json
import logging
from urllib.request import Request


from .decorators import endpoint
from .exceptions import BadRequest, MethodNotAllowed

logger = logging.getLogger('app')

class SmallViewSet:
    def parse_json_body(self, request: Request):
        if request.content_type != 'application/json':
            raise BadRequest('Invalid content type')
        return json.loads(request.body)

    def protect_create(self, request: Request):
        """
        Stub for adding any custom business logic to protect the create method.
        For example:
        - Check if the user is authenticated
        - Check if the user has validated their email
        - Throttle requests

        Recommended to call super().protect_create(request) in the subclass in case
        this library adds logic in the future.
        """
        pass

    def protect_list(self, request: Request):
        """
        Stub for adding any custom business logic to protect the list method.
        For example:
        - Check if the user is authenticated
        - Check if the user has validated their email
        - Throttle requests

        Recommended to call super().protect_create(request) in the subclass in case
        this library adds logic in the future.
        """
        pass

    def protect_retrieve(self, request: Request):
        """
        Stub for adding any custom business logic to protect the retrieve method.
        For example:
        - Check if the user is authenticated
        - Check if the user has validated their email
        - Throttle requests

        Recommended to call super().protect_create(request) in the subclass in case
        this library adds logic in the future.
        """
        pass

    def protect_update(self, request: Request):
        """
        Stub for adding any custom business logic to protect the update method.
        For example:
        - Check if the user is authenticated
        - Check if the user has validated their email
        - Throttle requests

        Recommended to call super().protect_create(request) in the subclass in case
        this library adds logic in the future.
        """
        pass

    def protect_delete(self, request: Request):
        """
        Stub for adding any custom business logic to protect the delete method.
        For example:
        - Check if the user is authenticated
        - Check if the user has validated their email
        - Throttle requests

        Recommended to call super().protect_create(request) in the subclass in case
        this library adds logic in the future.
        """
        pass

    @endpoint(allowed_methods=['GET', 'POST', 'PUT', 'DELETE', 'OPTIONS', 'HEAD'])
    async def default_router(self, request: Request, pk=None, *args, **kwargs):
        """
        This method routes requests to the appropriate method based on the HTTP method and presence of a primary key (pk).
        
        It also handles errors and returns appropriate JSON responses by using the decorator @endpoint(allowed_method=[]).
        
        GET/POST for collection endpoints and GET/PUT/PATCH/DELETE for detail endpoints.

        Example:
        ```
        # Note: AppViewSet is a subclass of SmallViewSet with overridden protect methods with more specific logic.

        class CommentViewSet(AppViewSet):
            def urlpatterns(self):
                return [
                    path('api/comments/',                     self.default_router, name='comments_collection'),
                    path('api/comments/<int:pk>/',            self.default_router, name='comments_detail'),
                    path('api/comments/<int:pk>/custom_put/', self.custom_put,     name='comments_custom_put_detail'),
                ]

            @endpoint(allowed_method=['POST'])
            def create(self, request: Request):
                self.protect_create(request)
                . . .

            @endpoint(allowed_method=['PUT', 'PATCH'])
            def update(self, request: Request, pk: int):
                self.protect_update(request)
                . . .

            @endpoint(allowed_method=['PUT'])
            def custom_put(self, request: Request, pk: int):
                self.protect_update(request)
                . . .

            @disable_endpoint
            @endpoint(allowed_method=['GET'])
            def some_disabled_endpoint(self, request: Request):
                self.protect_retrieve(request)
                . . .
        ```
        """
        func = None
        if pk is None:
            if request.method == 'GET':
                if hasattr(self, 'list'):
                    func = self.list

            elif request.method == 'POST':
                if hasattr(self, 'create'):
                    func = self.create
        else:
            if request.method == 'GET':
                if hasattr(self, 'retrieve'):
                    func = self.retrieve

            elif request.method == 'PUT':
                if hasattr(self, 'put'):
                    func = self.put

            elif request.method == 'PATCH':
                if hasattr(self, 'patch'):
                    func = self.patch

            elif request.method == 'DELETE':
                if hasattr(self, 'delete'):
                    func = self.delete

        if func is None:
            raise MethodNotAllowed(request.method)

        if pk is not None:
            kwargs['pk'] = pk

        if inspect.iscoroutinefunction(func):
            return await func(request, *args, **kwargs)
        else:
            return func(request, *args, **kwargs)

==> django_small_view_set-0.2.5.tar.gz: django_small_view_set-0.2.5/src/small_view_set/small_view_set.py <==
import inspect
import json
import logging
from urllib.request import Request


from .decorators import endpoint
from .exceptions import BadRequest, MethodNotAllowed

logger = logging.getLogger('app')

class SmallViewSet:
    def parse_json_body(self, request: Request):
        if request.content_type != 'application/json':
            raise BadRequest('Invalid content type')
        return json.loads(request.body)

    def protect_create(self, request: Request):
        """
        Stub for adding any custom business logic to protect the create method.
        For example:
        - Check if the user is authenticated
        - Check if the user has validated their email
        - Throttle requests

        Recommended to call super().protect_create(request) in the subclass in case
        this library adds logic in the future.
        """
        pass

    def protect_list(self, request: Request):
        """
        Stub for adding any custom business logic to protect the list method.
        For example:
        - Check if the user is authenticated
        - Check if the user has validated their email
        - Throttle requests

        Recommended to call super().protect_create(request) in the subclass in case
        this library adds logic in the future.
        """
        pass

    def protect_retrieve(self, request: Request):
        """
        Stub for adding any custom business logic to protect the retrieve method.
        For example:
        - Check if the user is authenticated
        - Check if the user has validated their email
        - Throttle requests

        Recommended to call super().protect_create(request) in the subclass in case
        this library adds logic in the future.
        """
        pass

    def protect_update(self, request: Request):
        """
        Stub for adding any custom business logic to protect the update method.
        For example:
        - Check if the user is authenticated
        - Check if the user has validated their email
        - Throttle requests

        Recommended to call super().protect_create(request) in the subclass in case
        this library adds logic in the future.
        """
        pass

    def protect_delete(self, request: Request):
        """
        Stub for adding any custom business logic to protect the delete method.
        For example:
        - Check if the user is authenticated
        - Check if the user has validated their email
        - Throttle requests

        Recommended to call super().protect_create(request) in the subclass in case
        this library adds logic in the future.
        """
        pass

    @endpoint(allowed_methods=['GET', 'POST', 'PUT', 'DELETE', 'OPTIONS', 'HEAD'])
    async def default_router_async(self, request: Request, pk=None, *args, **kwargs):
        """
        This method routes requests to the appropriate method based on the HTTP method and presence of a primary key (pk).
        
        It also handles errors and returns appropriate JSON responses by using the decorator @endpoint(allowed_method=[]).
        
        GET/POST for collection endpoints and GET/PUT/PATCH/DELETE for detail endpoints.

        Example:
        ```
        # Note: AppViewSet is a subclass of SmallViewSet with overridden protect methods with more specific logic.

        class CommentViewSet(AppViewSet):
            def urlpatterns(self):
                return [
                    path('api/comments/',                     self.default_router_async, name='comments_collection'),
                    path('api/comments/<int:pk>/',            self.default_router_async, name='comments_detail'),
                    path('api/comments/<int:pk>/custom_put/', self.custom_put,           name='comments_custom_put_detail'),
                ]

            @endpoint(allowed_method=['POST'])
            def create(self, request: Request):
                self.protect_create(request)
                . . .

            @endpoint(allowed_method=['PUT', 'PATCH'])
            def update(self, request: Request, pk: int):
                self.protect_update(request)
                . . .

            @endpoint(allowed_method=['PUT'])
            def custom_put(self, request: Request, pk: int):
                self.protect_update(request)
                . . .

            @endpoint(allowed_method=['GET'])
            @disable_endpoint
            def some_disabled_endpoint(self, request: Request):
                self.protect_retrieve(request)
                . . .
        ```
        """
        func = None
        if pk is None:
            if request.method == 'GET':
                if hasattr(self, 'list'):
                    func = self.list

            elif request.method == 'POST':
                if hasattr(self, 'create'):
                    func = self.create
        else:
            if request.method == 'GET':
                if hasattr(self, 'retrieve'):
                    func = self.retrieve

            elif request.method == 'PUT':
                if hasattr(self, 'put'):
                    func = self.put

            elif request.method == 'PATCH':
                if hasattr(self, 'patch'):
                    func = self.patch

            elif request.method == 'DELETE':
                if hasattr(self, 'delete'):
                    func = self.delete

        if func is None:
            raise MethodNotAllowed(request.method)
        if pk is not None:
            kwargs['pk'] = pk
        return await func(request, *args, **kwargs)


    @endpoint(allowed_methods=['GET', 'POST', 'PUT', 'DELETE', 'OPTIONS', 'HEAD'])
    def default_router(self, request: Request, pk=None, *args, **kwargs):
        """
        This method routes requests to the appropriate method based on the HTTP method and presence of a primary key (pk).
        
        It also handles errors and returns appropriate JSON responses by using the decorator @endpoint(allowed_method=[]).
        
        GET/POST for collection endpoints and GET/PUT/PATCH/DELETE for detail endpoints.

        Example:
        ```
        # Note: AppViewSet is a subclass of SmallViewSet with overridden protect methods with more specific logic.

        class CommentViewSet(AppViewSet):
            def urlpatterns(self):
                return [
                    path('api/comments/',                     self.default_router, name='comments_collection'),
                    path('api/comments/<int:pk>/',            self.default_router, name='comments_detail'),
                    path('api/comments/<int:pk>/custom_put/', self.custom_put,     name='comments_custom_put_detail'),
                ]

            @endpoint(allowed_method=['POST'])
            def create(self, request: Request):
                self.protect_create(request)
                . . .

            @endpoint(allowed_method=['PUT', 'PATCH'])
            def update(self, request: Request, pk: int):
                self.protect_update(request)
                . . .

            @endpoint(allowed_method=['PUT'])
            def custom_put(self, request: Request, pk: int):
                self.protect_update(request)
                . . .

            @disable_endpoint
            @endpoint(allowed_method=['GET'])
            def some_disabled_endpoint(self, request: Request):
                self.protect_retrieve(request)
                . . .
        ```
        """
        func = None
        if pk is None:
            if request.method == 'GET':
                if hasattr(self, 'list'):
                    func = self.list

            elif request.method == 'POST':
                if hasattr(self, 'create'):
                    func = self.create
        else:
            if request.method == 'GET':
                if hasattr(self, 'retrieve'):
                    func = self.retrieve

            elif request.method == 'PUT':
                if hasattr(self, 'put'):
                    func = self.put

            elif request.method == 'PATCH':
                if hasattr(self, 'patch'):
                    func = self.patch

            elif request.method == 'DELETE':
                if hasattr(self, 'delete'):
                    func = self.delete

        if func is None:
            raise MethodNotAllowed(request.method)
        if pk is not None:
            kwargs['pk'] = pk
        return func(request, *args, **kwargs)
